@@ -11,10 +11,12 @@ Salesforce database backend for Django.
 
 import logging
 import requests
+import threading
 
 from django.core.exceptions import ImproperlyConfigured
 from django.db.backends import BaseDatabaseFeatures, BaseDatabaseWrapper
 from django.db.backends.signals import connection_created
+from django.conf import settings
 
 from salesforce.auth import SalesforceAuth, authenticate
 from salesforce.backend.client import DatabaseClient
@@ -33,6 +35,7 @@ except ImportError:
 
 log = logging.getLogger(__name__)
 
+connect_lock = threading.Lock()
 
 class SalesforceError(DatabaseError):
 	"""
@@ -112,14 +115,32 @@ class DatabaseWrapper(BaseDatabaseWrapper):
 		self.creation = DatabaseCreation(self)
 		self.introspection = DatabaseIntrospection(self)
 		self.validation = DatabaseValidation(self)
-		self.sf_session = requests.Session()
-		self.sf_session.auth = SalesforceAuth(db_alias=alias)
-		sf_instance_url = authenticate(alias, settings_dict=settings_dict)['instance_url']
-		sf_requests_adapter = requests.adapters.HTTPAdapter(max_retries=MAX_RETRIES)
-		self.sf_session.mount(sf_instance_url, sf_requests_adapter)
-		# Additional header works, but the improvement unmeasurable for me.
-		# (less than SF speed fluctuation)
-		#self.sf_session.header = {'accept-encoding': 'gzip, deflate', 'connection': 'keep-alive'}
+		self._sf_session = None
+		if not getattr(settings, 'SF_LAZY_CONNECT', False):
+			self.make_session()
+
+	def make_session(self):
+		"""Authenticate and get the name of assigned SFDC data server"""
+		with connect_lock:
+			if self._sf_session is None:
+				if self.settings_dict['USER'] == 'dynamic auth':
+					sf_instance_url = self._sf_session or self.settings_dict['HOST']
+				else:
+					sf_instance_url = authenticate(self.alias, settings_dict=self.settings_dict)['instance_url']
+				sf_session = requests.Session()
+				sf_session.auth = SalesforceAuth(db_alias=self.alias)
+				sf_requests_adapter = requests.adapters.HTTPAdapter(max_retries=MAX_RETRIES)
+				sf_session.mount(sf_instance_url, sf_requests_adapter)
+				# Additional header works, but the improvement unmeasurable for me.
+				# (less than SF speed fluctuation)
+				#sf_session.header = {'accept-encoding': 'gzip, deflate', 'connection': 'keep-alive'}
+				self._sf_session = sf_session
+
+	@property
+	def sf_session(self):
+		if self._sf_session is None:
+			self.make_session()
+		return self._sf_session
 
 	def get_connection_params(self):
 		settings_dict = self.settings_dict
