@@ -40,11 +40,9 @@ class SalesforceModelBase(ModelBase):
 	def __new__(cls, name, bases, attrs):
 		attr_meta = attrs.get('Meta', None)
 		supplied_db_table = getattr(attr_meta, 'db_table', None)
-		if hasattr(attr_meta, 'sf_pk'):
-			cls.sf_pk = attr_meta.sf_pk
 		result = super(SalesforceModelBase, cls).__new__(cls, name, bases, attrs)
-		if(models.Model not in bases and supplied_db_table is None):
-			result._meta.db_table = name
+		if models.Model not in bases and supplied_db_table is None:
+			result._meta.db_table = result._meta.concrete_model._meta.object_name
 		return result
 
 	def add_to_class(cls, name, value):
@@ -89,7 +87,9 @@ class SalesforceModel(with_metaclass(SalesforceModelBase, models.Model)):
 		managed = False
 		abstract = True
 
-	Id = fields.SalesforceAutoField(primary_key=True)
+	# Name of primary key 'Id' can be easily changed to 'id'
+	# by "settings.SF_PK='id'".
+	Id = fields.SalesforceAutoField(primary_key=True, name=SF_PK, db_column='Id')
 
 
 Model = SalesforceModel
