@@ -11,11 +11,9 @@ from django.forms import widgets
 from django.http import HttpResponse
 
 from salesforce.testrunner.example import models
-from salesforce.admin import RoutedModelAdmin
 import salesforce
 
-# This example is commented out in order to demonstrate capabilities of all models
-class AccountAdmin(RoutedModelAdmin):
+class AccountAdmin(admin.ModelAdmin):
 	#list_display = ('Salutation', 'Name', 'PersonEmail')
 	list_display = ('Name', 'Phone')
 admin.site.register(models.Account, AccountAdmin)
@@ -24,7 +22,7 @@ admin.site.register(models.Account, AccountAdmin)
 # Can be improved for fields that are only not creatable but are updateable or viceversa.
 for mdl in [x for x in models.__dict__.values() if hasattr(x, '_meta') and hasattr(x._meta, 'db_table') and not x._meta.abstract]:
 	try:
-		admin.site.register(mdl, type(type(mdl).__name__ + 'Admin', (RoutedModelAdmin,), {
+		admin.site.register(mdl, type(type(mdl).__name__ + 'Admin', (admin.ModelAdmin,), {
 			'readonly_fields': [x.name for x in mdl._meta.fields if getattr(x, 'sf_read_only', 0)]}))
 	except admin.sites.AlreadyRegistered:
 		pass
